Hash

Trait Hash 

1.6.0 · Source
pub trait Hash {
    // Required method
    fn hash<H>(&self, state: &mut H)
       where H: Hasher;

    // Provided method
    fn hash_slice<H>(data: &[Self], state: &mut H)
       where H: Hasher,
             Self: Sized { ... }
}
A hashable type.

Types implementing Hash are able to be hashed with an instance of Hasher.

Implementing Hash

You can derive Hash with #[derive(Hash)] if all fields implement Hash. The resulting hash will be the combination of the values from calling hash on each field.

#[derive(Hash)]
struct Rustacean {
    name: String,
    country: String,
}

If you need more control over how a value is hashed, you can of course implement the Hash trait yourself:

use std::hash::{Hash, Hasher};

struct Person {
    id: u32,
    name: String,
    phone: u64,
}

impl Hash for Person {
    fn hash<H: Hasher>(&self, state: &mut H) {
        self.id.hash(state);
        self.phone.hash(state);
    }
}

Hash and Eq

When implementing both Hash and Eq, it is important that the following property holds:

k1 == k2 -> hash(k1) == hash(k2)

In other words, if two keys are equal, their hashes must also be equal. HashMap and HashSet both rely on this behavior.

Thankfully, you won’t need to worry about upholding this property when deriving both Eq and Hash with #[derive(PartialEq, Eq, Hash)].

Violating this property is a logic error. The behavior resulting from a logic error is not specified, but users of the trait must ensure that such logic errors do not result in undefined behavior. This means that unsafe code must not rely on the correctness of these methods.

Prefix collisions

Implementations of hash should ensure that the data they pass to the Hasher are prefix-free. That is, values which are not equal should cause two different sequences of values to be written, and neither of the two sequences should be a prefix of the other.

For example, the standard implementation of Hash for &str passes an extra 0xFF byte to the Hasher so that the values ("ab", "c") and ("a", "bc") hash differently.

Portability

Due to differences in endianness and type sizes, data fed by Hash to a Hasher should not be considered portable across platforms. Additionally the data passed by most standard library types should not be considered stable between compiler versions.

This means tests shouldn’t probe hard-coded hash values or data fed to a Hasher and instead should check consistency with Eq.

Serialization formats intended to be portable between platforms or compiler versions should either avoid encoding hashes or only rely on Hash and Hasher implementations that provide additional guarantees.

Required Methods

1.0.0 · Source

fn hash<H>(&self, state: &mut H)
where H: Hasher,

Feeds this value into the given Hasher.

Examples
use std::hash::{DefaultHasher, Hash, Hasher};

let mut hasher = DefaultHasher::new();
7920.hash(&mut hasher);
println!("Hash is {:x}!", hasher.finish());

Provided Methods

1.3.0 · Source

fn hash_slice<H>(data: &[Self], state: &mut H)
where H: Hasher, Self: Sized,

Feeds a slice of this type into the given Hasher.

This method is meant as a convenience, but its implementation is also explicitly left unspecified. It isn’t guaranteed to be equivalent to repeated calls of hash and implementations of Hash should keep that in mind and call hash themselves if the slice isn’t treated as a whole unit in the PartialEq implementation.

For example, a VecDeque implementation might naïvely call as_slices and then hash_slice on each slice, but this is wrong since the two slices can change with a call to make_contiguous without affecting the PartialEq result. Since these slices aren’t treated as singular units, and instead part of a larger deque, this method cannot be used.

Examples
use std::hash::{DefaultHasher, Hash, Hasher};

let mut hasher = DefaultHasher::new();
let numbers = [6, 28, 496, 8128];
Hash::hash_slice(&numbers, &mut hasher);
println!("Hash is {:x}!", hasher.finish());

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl Hash for Format

Source

impl Hash for gimli::common::SectionId

Source

impl Hash for RunTimeEndian

Source

impl Hash for CallFrameInstruction

Source

impl Hash for Address

Source

impl Hash for Reference

Source

impl Hash for LineString

Source

impl Hash for gimli::write::loc::Location

Source

impl Hash for gimli::write::range::Range

Source

impl Hash for Level

Source

impl Hash for LevelFilter

Source

impl Hash for AddressSize

Source

impl Hash for object::common::Architecture

Source

impl Hash for object::common::BinaryFormat

Source

impl Hash for ComdatKind

Source

impl Hash for FileFlags

Source

impl Hash for RelocationEncoding

Source

impl Hash for RelocationFlags

Source

impl Hash for RelocationKind

Source

impl Hash for SectionFlags

Source

impl Hash for SectionKind

Source

impl Hash for object::common::SegmentFlags

Source

impl Hash for SubArchitecture

Source

impl Hash for SymbolKind

Source

impl Hash for SymbolScope

Source

impl Hash for object::endian::Endianness

Source

impl Hash for ImportType

Source

impl Hash for CompressionFormat

Source

impl Hash for FileKind

Source

impl Hash for ObjectKind

Source

impl Hash for RelocationTarget

Source

impl Hash for object::read::SymbolSection

Source

impl Hash for Mangling

Source

impl Hash for StandardSection

Source

impl Hash for StandardSegment

Source

impl Hash for object::write::SymbolSection

Source

impl Hash for Op

Source

impl Hash for CDataModel

Source

impl Hash for Size

Source

impl Hash for Aarch64Architecture

Source

impl Hash for target_lexicon::targets::Architecture

Source

impl Hash for ArmArchitecture

Source

impl Hash for target_lexicon::targets::BinaryFormat

Source

impl Hash for CleverArchitecture

Source

impl Hash for CustomVendor

Source

impl Hash for Environment

Source

impl Hash for Mips32Architecture

Source

impl Hash for Mips64Architecture

Source

impl Hash for OperatingSystem

Source

impl Hash for Riscv32Architecture

Source

impl Hash for Riscv64Architecture

Source

impl Hash for Vendor

Source

impl Hash for X86_32Architecture

Source

impl Hash for CallingConvention

Source

impl Hash for target_lexicon::triple::Endianness

Source

impl Hash for PointerWidth

Source

impl Hash for DiscriminantSize

Source

impl Hash for CanonicalOptionsDataModel

Source

impl Hash for wasmtime_environ::component::dfg::CoreDef

Source

impl Hash for Trampoline

Source

impl Hash for wasmtime_environ::component::CoreDef

Source

impl Hash for DataModel

Source

impl Hash for FixedEncoding

Source

impl Hash for FlatType

Source

impl Hash for InterfaceType

Source

impl Hash for LocalDataModel

Source

impl Hash for StringEncoding

Source

impl Hash for Transcode

Source

impl Hash for Abi

Source

impl Hash for Collector

Source

impl Hash for ConstOp

Source

impl Hash for EngineOrModuleTypeIndex

Source

impl Hash for EntityIndex

Source

impl Hash for FuncKey

Source

impl Hash for FuncKeyKind

Source

impl Hash for HostCall

Source

impl Hash for IndexType

Source

impl Hash for IntraModuleInlining

Source

impl Hash for Trap

Source

impl Hash for WasmCompositeInnerType

Source

impl Hash for WasmHeapTopType

Source

impl Hash for WasmHeapType

Source

impl Hash for WasmStorageType

Source

impl Hash for WasmValType

Source

impl Hash for AsciiChar

1.0.0 · Source

impl Hash for wasmtime_environ::__core::cmp::Ordering

1.44.0 · Source

impl Hash for Infallible

1.7.0 · Source

impl Hash for IpAddr

Source

impl Hash for Ipv6MulticastScope

1.0.0 · Source

impl Hash for SocketAddr

1.55.0 · Source

impl Hash for IntErrorKind

1.0.0 · Source

impl Hash for wasmtime_environ::__core::sync::atomic::Ordering

1.0.0 · Source

impl Hash for ErrorKind

1.0.0 · Source

impl Hash for bool

1.0.0 · Source

impl Hash for char

1.0.0 · Source

impl Hash for i8

1.0.0 · Source

impl Hash for i16

1.0.0 · Source

impl Hash for i32

1.0.0 · Source

impl Hash for i64

1.0.0 · Source

impl Hash for i128

1.0.0 · Source

impl Hash for isize

1.29.0 · Source

impl Hash for !

1.0.0 · Source

impl Hash for str

1.0.0 · Source

impl Hash for u8

1.0.0 · Source

impl Hash for u16

1.0.0 · Source

impl Hash for u32

1.0.0 · Source

impl Hash for u64

1.0.0 · Source

impl Hash for u128

1.0.0 · Source

impl Hash for ()

1.0.0 · Source

impl Hash for usize

Source

impl Hash for DebugTypeSignature

Source

impl Hash for DwoId

Source

impl Hash for Encoding

Source

impl Hash for LineEncoding

Source

impl Hash for Register

Source

impl Hash for DwAccess

Source

impl Hash for DwAddr

Source

impl Hash for DwAt

Source

impl Hash for DwAte

Source

impl Hash for DwCc

Source

impl Hash for DwCfa

Source

impl Hash for DwChildren

Source

impl Hash for DwDefaulted

Source

impl Hash for DwDs

Source

impl Hash for DwDsc

Source

impl Hash for DwEhPe

Source

impl Hash for DwEnd

Source

impl Hash for DwForm

Source

impl Hash for DwId

Source

impl Hash for DwIdx

Source

impl Hash for DwInl

Source

impl Hash for DwLang

Source

impl Hash for DwLle

Source

impl Hash for DwLnct

Source

impl Hash for DwLne

Source

impl Hash for DwLns

Source

impl Hash for DwMacinfo

Source

impl Hash for DwMacro

Source

impl Hash for DwOp

Source

impl Hash for DwOrd

Source

impl Hash for DwRle

Source

impl Hash for DwSect

Source

impl Hash for DwSectV2

Source

impl Hash for DwTag

Source

impl Hash for DwUt

Source

impl Hash for DwVirtuality

Source

impl Hash for DwVis

Source

impl Hash for gimli::endianity::BigEndian

Source

impl Hash for gimli::endianity::LittleEndian

Source

impl Hash for gimli::read::rnglists::Range

Source

impl Hash for CieId

Source

impl Hash for CommonInformationEntry

Source

impl Hash for FileId

Source

impl Hash for DirectoryId

Source

impl Hash for LocationList

Source

impl Hash for LocationListId

Source

impl Hash for gimli::write::op::Expression

Source

impl Hash for RangeList

Source

impl Hash for RangeListId

Source

impl Hash for LineStringId

Source

impl Hash for StringId

Source

impl Hash for UnitEntryId

Source

impl Hash for UnitId

Source

impl Hash for object::endian::BigEndian

Source

impl Hash for object::endian::LittleEndian

Source

impl Hash for CompressedFileRange

Source

impl Hash for object::read::SectionIndex

Source

impl Hash for object::read::SymbolIndex

Source

impl Hash for object::write::elf::writer::SectionIndex

Source

impl Hash for object::write::elf::writer::SymbolIndex

Source

impl Hash for ComdatId

Source

impl Hash for object::write::SectionId

Source

impl Hash for SymbolId

Source

impl Hash for BuildMetadata

Source

impl Hash for Comparator

Source

impl Hash for Prerelease

Source

impl Hash for Version

Source

impl Hash for VersionReq

Source

impl Hash for DefaultToHost

Source

impl Hash for DefaultToUnknown

Source

impl Hash for DeploymentTarget

Source

impl Hash for Triple

Source

impl Hash for AdapterId

Source

impl Hash for AdapterModuleId

Source

impl Hash for CallbackId

Source

impl Hash for CanonicalOptions

Source

impl Hash for FutureInfo

Source

impl Hash for InstanceId

Source

impl Hash for MemoryId

Source

impl Hash for OptionsId

Source

impl Hash for PostReturnId

Source

impl Hash for ReallocId

Source

impl Hash for StreamInfo

Source

impl Hash for TableId

Source

impl Hash for Adapter

Source

impl Hash for AdapterOptions

Source

impl Hash for CanonicalAbiInfo

Source

impl Hash for ComponentBuiltinFunctionIndex

Source

impl Hash for ComponentFuncIndex

Source

impl Hash for ComponentIndex

Source

impl Hash for ComponentInstanceIndex

Source

impl Hash for ComponentTypeIndex

Source

impl Hash for ComponentUpvarIndex

Source

impl Hash for DefinedResourceIndex

Source

impl Hash for ExportIndex

Source

impl Hash for ImportIndex

Source

impl Hash for LoweredIndex

Source

impl Hash for ModuleIndex

Source

impl Hash for ModuleInstanceIndex

Source

impl Hash for ModuleUpvarIndex

Source

impl Hash for OptionsIndex

Source

impl Hash for RecordField

Source

impl Hash for ResourceIndex

Source

impl Hash for RuntimeCallbackIndex

Source

impl Hash for RuntimeComponentInstanceIndex

Source

impl Hash for RuntimeImportIndex

Source

impl Hash for RuntimeInstanceIndex

Source

impl Hash for RuntimeMemoryIndex

Source

impl Hash for RuntimePostReturnIndex

Source

impl Hash for RuntimeReallocIndex

Source

impl Hash for RuntimeTableIndex

Source

impl Hash for StaticComponentIndex

Source

impl Hash for TrampolineIndex

Source

impl Hash for TypeComponentGlobalErrorContextTableIndex

Source

impl Hash for TypeComponentIndex

Source

impl Hash for TypeComponentInstanceIndex

Source

impl Hash for TypeComponentLocalErrorContextTableIndex

Source

impl Hash for TypeEnum

Source

impl Hash for TypeEnumIndex

Source

impl Hash for TypeErrorContextTable

Source

impl Hash for TypeFlags

Source

impl Hash for TypeFlagsIndex

Source

impl Hash for TypeFunc

Source

impl Hash for TypeFuncIndex

Source

impl Hash for TypeFuture

Source

impl Hash for TypeFutureIndex

Source

impl Hash for TypeFutureTable

Source

impl Hash for TypeFutureTableIndex

Source

impl Hash for TypeList

Source

impl Hash for TypeListIndex

Source

impl Hash for TypeModuleIndex

Source

impl Hash for TypeOption

Source

impl Hash for TypeOptionIndex

Source

impl Hash for TypeRecord

Source

impl Hash for TypeRecordIndex

Source

impl Hash for TypeResourceTable

Source

impl Hash for TypeResourceTableIndex

Source

impl Hash for TypeResult

Source

impl Hash for TypeResultIndex

Source

impl Hash for TypeStream

Source

impl Hash for TypeStreamIndex

Source

impl Hash for TypeStreamTable

Source

impl Hash for TypeStreamTableIndex

Source

impl Hash for TypeTuple

Source

impl Hash for TypeTupleIndex

Source

impl Hash for TypeVariant

Source

impl Hash for TypeVariantIndex

Source

impl Hash for VariantInfo

1.0.0 · Source

impl Hash for String

Source

impl Hash for BuiltinFunctionIndex

Source

impl Hash for ConstExpr

Source

impl Hash for DataIndex

Source

impl Hash for DefinedFuncIndex

Source

impl Hash for DefinedGlobalIndex

Source

impl Hash for DefinedMemoryIndex

Source

impl Hash for DefinedTableIndex

Source

impl Hash for DefinedTagIndex

Source

impl Hash for ElemIndex

Source

impl Hash for EngineInternedRecGroupIndex

Source

impl Hash for FuncIndex

Source

impl Hash for FuncKeyIndex

Source

impl Hash for FuncKeyNamespace

Source

impl Hash for FuncRefIndex

Source

impl Hash for Global

Source

impl Hash for GlobalIndex

Source

impl Hash for Limits

Source

impl Hash for Memory

Source

impl Hash for MemoryIndex

Source

impl Hash for ModuleInternedRecGroupIndex

Source

impl Hash for ModuleInternedTypeIndex

Source

impl Hash for OwnedMemoryIndex

Source

impl Hash for RecGroupRelativeTypeIndex

Source

impl Hash for StaticModuleIndex

Source

impl Hash for Table

Source

impl Hash for TableIndex

Source

impl Hash for Tag

Source

impl Hash for TagIndex

Source

impl Hash for Tunables

Source

impl Hash for TypeIndex

Source

impl Hash for VMSharedTypeIndex

Source

impl Hash for WasmArrayType

Source

impl Hash for WasmCompositeType

Source

impl Hash for WasmContType

Source

impl Hash for WasmExnType

Source

impl Hash for WasmFieldType

Source

impl Hash for WasmFuncType

Source

impl Hash for WasmRecGroup

Source

impl Hash for WasmRefType

Source

impl Hash for WasmStructType

Source

impl Hash for WasmSubType

1.28.0 · Source

impl Hash for Layout

1.0.0 · Source

impl Hash for TypeId

Source

impl Hash for ByteStr

1.64.0 · Source

impl Hash for CStr

1.0.0 · Source

impl Hash for Error

1.33.0 · Source

impl Hash for PhantomPinned

1.0.0 · Source

impl Hash for Ipv4Addr

1.0.0 · Source

impl Hash for Ipv6Addr

1.0.0 · Source

impl Hash for SocketAddrV4

1.0.0 · Source

impl Hash for SocketAddrV6

1.0.0 · Source

impl Hash for RangeFull

1.10.0 · Source

impl Hash for wasmtime_environ::__core::panic::Location<'_>

Source

impl Hash for Alignment

1.3.0 · Source

impl Hash for Duration

Source

impl Hash for ByteString

1.64.0 · Source

impl Hash for CString

1.0.0 · Source

impl Hash for OsStr

1.0.0 · Source

impl Hash for OsString

1.1.0 · Source

impl Hash for FileType

Source

impl Hash for UCred

1.0.0 · Source

impl Hash for Path

1.0.0 · Source

impl Hash for PathBuf

1.0.0 · Source

impl Hash for PrefixComponent<'_>

1.19.0 · Source

impl Hash for ThreadId

1.8.0 · Source

impl Hash for Instant

1.8.0 · Source

impl Hash for SystemTime



impl Hash for AbstractHeapType



impl Hash for AbstractHeapType



impl Hash for AliasableResourceId



impl Hash for AnyTypeId



impl Hash for ArrayType



impl Hash for ArrayType



impl Hash for ComdatSymbolKind



impl Hash for ComponentAnyTypeId



impl Hash for ComponentCoreInstanceTypeId



impl Hash for ComponentCoreModuleTypeId



impl Hash for ComponentCoreTypeId



impl Hash for ComponentDefinedTypeId



impl Hash for ComponentFuncTypeId



impl Hash for ComponentInstanceTypeId



impl Hash for ComponentName



impl Hash for ComponentNameKind<'_>



impl Hash for ComponentTypeId



impl Hash for ComponentTypeRef



impl Hash for ComponentValType



impl Hash for ComponentValueTypeId



impl Hash for CompositeInnerType



impl Hash for CompositeType



impl Hash for ContType



impl Hash for ContType



impl Hash for CoreTypeId



impl Hash for ExportKind



impl Hash for FieldType



impl Hash for FieldType



impl Hash for FuncType



impl Hash for FuncType



impl Hash for GlobalType



impl Hash for GlobalType



impl Hash for HeapType



impl Hash for HeapType



impl Hash for Ieee32



impl Hash for Ieee32



impl Hash for Ieee64



impl Hash for Ieee64



impl Hash for KebabStr



impl Hash for KebabString



impl Hash for MemoryType



impl Hash for MemoryType



impl Hash for Ordering



impl Hash for PackedIndex



impl Hash for PrimitiveValType



impl Hash for RecGroup



impl Hash for RecGroupId



impl Hash for RefType



impl Hash for RefType



impl Hash for RelocAddendKind



impl Hash for RelocationEntry



impl Hash for RelocationType



impl Hash for ResourceId



impl Hash for SegmentFlags



impl Hash for StorageType



impl Hash for StorageType



impl Hash for StructType



impl Hash for StructType



impl Hash for SubType



impl Hash for SymbolFlags



impl Hash for TableType



impl Hash for TableType



impl Hash for TypeBounds



impl Hash for UnpackedIndex



impl Hash for V128



impl Hash for ValType



impl Hash for ValType



impl Hash for ValidatorId



impl Hash for WasmFeatures

Source

impl<'a> Hash for FlagValue<'a>

1.0.0 · Source

impl<'a> Hash for Component<'a>

1.0.0 · Source

impl<'a> Hash for Prefix<'a>

Source

impl<'a> Hash for Metadata<'a>

Source

impl<'a> Hash for MetadataBuilder<'a>

Source

impl<'a> Hash for PhantomContravariantLifetime<'a>

Source

impl<'a> Hash for PhantomCovariantLifetime<'a>

Source

impl<'a> Hash for PhantomInvariantLifetime<'a>



impl<'a> Hash for BinaryReader<'a>



impl<'a> Hash for DependencyName<'a>



impl<'a> Hash for HashName<'a>



impl<'a> Hash for InterfaceName<'a>



impl<'a> Hash for ResourceFunc<'a>



impl<'a> Hash for UrlName<'a>

Source

impl<'data> Hash for CompressedData<'data>

Source

impl<'data> Hash for ObjectMapEntry<'data>

Source

impl<'data> Hash for ObjectMapFile<'data>

Source

impl<'data> Hash for SymbolMapName<'data>

Source

impl<'input, Endian> Hash for EndianSlice<'input, Endian>
where Endian: Hash + Endianity,

Source

impl<A> Hash for SmallVec<A>
where A: Array, <A as Array>::Item: Hash,

1.0.0 · Source

impl<B> Hash for Cow<'_, B>
where B: Hash + ToOwned + ?Sized,

1.55.0 · Source

impl<B, C> Hash for ControlFlow<B, C>
where B: Hash, C: Hash,

Source

impl<Dyn> Hash for DynMetadata<Dyn>
where Dyn: ?Sized,

Source

impl<E> Hash for I16Bytes<E>
where E: Hash + Endian,

Source

impl<E> Hash for I32Bytes<E>
where E: Hash + Endian,

Source

impl<E> Hash for I64Bytes<E>
where E: Hash + Endian,

Source

impl<E> Hash for U16Bytes<E>
where E: Hash + Endian,

Source

impl<E> Hash for U32Bytes<E>
where E: Hash + Endian,

Source

impl<E> Hash for U64Bytes<E>
where E: Hash + Endian,

1.4.0 · Source

impl<F> Hash for F
where F: FnPtr,

1.0.0 · Source

impl<Idx> Hash for wasmtime_environ::__core::ops::Range<Idx>
where Idx: Hash,

1.0.0 · Source

impl<Idx> Hash for wasmtime_environ::__core::ops::RangeFrom<Idx>
where Idx: Hash,

1.26.0 · Source

impl<Idx> Hash for wasmtime_environ::__core::ops::RangeInclusive<Idx>
where Idx: Hash,

1.0.0 · Source

impl<Idx> Hash for RangeTo<Idx>
where Idx: Hash,

1.26.0 · Source

impl<Idx> Hash for wasmtime_environ::__core::ops::RangeToInclusive<Idx>
where Idx: Hash,

Source

impl<Idx> Hash for wasmtime_environ::__core::range::Range<Idx>
where Idx: Hash,

Source

impl<Idx> Hash for wasmtime_environ::__core::range::RangeFrom<Idx>
where Idx: Hash,

Source

impl<Idx> Hash for wasmtime_environ::__core::range::RangeInclusive<Idx>
where Idx: Hash,

Source

impl<Idx> Hash for wasmtime_environ::__core::range::RangeToInclusive<Idx>
where Idx: Hash,

Source

impl<K, V> Hash for indexmap::map::slice::Slice<K, V>
where K: Hash, V: Hash,

Source

impl<K, V> Hash for PrimaryMap<K, V>
where K: Hash + EntityRef, V: Hash,

Source

impl<K, V> Hash for SecondaryMap<K, V>
where K: Hash + EntityRef, V: Hash + Clone,

1.0.0 · Source

impl<K, V, A> Hash for BTreeMap<K, V, A>
where K: Hash, V: Hash, A: Allocator + Clone,

1.41.0 · Source

impl<Ptr> Hash for Pin<Ptr>
where Ptr: Deref, <Ptr as Deref>::Target: Hash,

Source

impl<R> Hash for LocationListEntry<R>
where R: Hash + Reader,

Source

impl<R> Hash for gimli::read::op::Expression<R>
where R: Hash + Reader,

Source

impl<Section, Symbol> Hash for object::common::SymbolFlags<Section, Symbol>
where Section: Hash, Symbol: Hash,

Source

impl<T> Hash for UnitSectionOffset<T>
where T: Hash,

1.17.0 · Source

impl<T> Hash for Bound<T>
where T: Hash,

1.0.0 · Source

impl<T> Hash for Option<T>
where T: Hash,

1.36.0 · Source

impl<T> Hash for Poll<T>
where T: Hash,

1.0.0 · Source

impl<T> Hash for *const T
where T: ?Sized,

1.0.0 · Source

impl<T> Hash for *mut T
where T: ?Sized,

1.0.0 · Source

impl<T> Hash for &T
where T: Hash + ?Sized,

1.0.0 · Source

impl<T> Hash for &mut T
where T: Hash + ?Sized,

1.0.0 · Source

impl<T> Hash for [T]
where T: Hash,

1.0.0 · Source

impl<T> Hash for (T₁, T₂, …, Tₙ)
where T: Hash,

This trait is implemented for tuples up to twelve items long.

Source

impl<T> Hash for DebugAbbrevOffset<T>
where T: Hash,

Source

impl<T> Hash for DebugFrameOffset<T>
where T: Hash,

Source

impl<T> Hash for DebugInfoOffset<T>
where T: Hash,

Source

impl<T> Hash for DebugMacinfoOffset<T>
where T: Hash,

Source

impl<T> Hash for DebugMacroOffset<T>
where T: Hash,

Source

impl<T> Hash for DebugTypesOffset<T>
where T: Hash,

Source

impl<T> Hash for EhFrameOffset<T>
where T: Hash,

Source

impl<T> Hash for LocationListsOffset<T>
where T: Hash,

Source

impl<T> Hash for RangeListsOffset<T>
where T: Hash,

Source

impl<T> Hash for RawRangeListsOffset<T>
where T: Hash,

Source

impl<T> Hash for UnitOffset<T>
where T: Hash,

Source

impl<T> Hash for indexmap::set::slice::Slice<T>
where T: Hash,

Source

impl<T> Hash for PackedOption<T>
where T: Hash + ReservedValue,

Source

impl<T> Hash for EntityList<T>

Source

impl<T> Hash for ListPool<T>

1.19.0 · Source

impl<T> Hash for Reverse<T>
where T: Hash,

Source

impl<T> Hash for PhantomContravariant<T>
where T: ?Sized,

Source

impl<T> Hash for PhantomCovariant<T>
where T: ?Sized,

1.0.0 · Source

impl<T> Hash for PhantomData<T>
where T: ?Sized,

Source

impl<T> Hash for PhantomInvariant<T>
where T: ?Sized,

1.21.0 · Source

impl<T> Hash for Discriminant<T>

1.20.0 · Source

impl<T> Hash for ManuallyDrop<T>
where T: Hash + ?Sized,

1.28.0 · Source

impl<T> Hash for NonZero<T>

1.74.0 · Source

impl<T> Hash for Saturating<T>
where T: Hash,

1.0.0 · Source

impl<T> Hash for Wrapping<T>
where T: Hash,

1.25.0 · Source

impl<T> Hash for NonNull<T>
where T: ?Sized,

1.0.0 · Source

impl<T, A> Hash for Box<T, A>
where T: Hash + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Hash for Vec<T, A>
where T: Hash, A: Allocator,

The hash of a vector is the same as that of the corresponding slice, as required by the core::borrow::Borrow implementation.

use std::hash::BuildHasher;

let b = std::hash::RandomState::new();
let v: Vec<u8> = vec![0xa8, 0x3c, 0x09];
let s: &[u8] = &[0xa8, 0x3c, 0x09];
assert_eq!(b.hash_one(v), b.hash_one(s));
1.0.0 · Source

impl<T, A> Hash for BTreeSet<T, A>
where T: Hash, A: Allocator + Clone,

1.0.0 · Source

impl<T, A> Hash for LinkedList<T, A>
where T: Hash, A: Allocator,

1.0.0 · Source

impl<T, A> Hash for VecDeque<T, A>
where T: Hash, A: Allocator,

1.0.0 · Source

impl<T, A> Hash for Rc<T, A>
where T: Hash + ?Sized, A: Allocator,

Source

impl<T, A> Hash for UniqueRc<T, A>
where T: Hash + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Hash for Arc<T, A>
where T: Hash + ?Sized, A: Allocator,

Source

impl<T, A> Hash for UniqueArc<T, A>
where T: Hash + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, E> Hash for Result<T, E>
where T: Hash, E: Hash,

1.0.0 · Source

impl<T, const N: usize> Hash for [T; N]
where T: Hash,

The hash of an array is the same as that of the corresponding slice, as required by the Borrow implementation.

use std::hash::BuildHasher;

let b = std::hash::RandomState::new();
let a: [u8; 3] = [0xa8, 0x3c, 0x09];
let s: &[u8] = &[0xa8, 0x3c, 0x09];
assert_eq!(b.hash_one(a), b.hash_one(s));
Source

impl<T, const N: usize> Hash for Simd<T, N>

Source

impl<T: Hash> Hash for ExportItem<T>

Source

impl<T: Hash> Hash for wasmtime_environ::component::dfg::CoreExport<T>

Source

impl<T: Hash> Hash for wasmtime_environ::component::CoreExport<T>

Source

impl<Y, R> Hash for CoroutineState<Y, R>
where Y: Hash, R: Hash,